@@ -1,19 +1,20 @@
 package Locale::CLDR::Locales::Is::Any;
 
 # This file auto generated
-#	on Sat  6 Feb 10:46:20 am GMT
+#	on Sun 24 Apr  8:35:08 am GMT
 
 use version;
 
-our $VERSION = version->declare('v0.28.3');
+our $VERSION = version->declare('v0.29.0');
 
 use v5.10.1;
 use mro 'c3';
 use if $^V ge v5.12.0, feature => 'unicode_strings';
 
-use Moose;
+use Moo;
 
 extends('Locale::CLDR::Locales::Is');
 
-no Moose;
-__PACKAGE__->meta->make_immutable;
+no Moo;
+
+1;
